# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['tyrannosaurus']

package_data = \
{'': ['*']}

install_requires = \
['importlib-metadata>=1.6,<2.0', 'tomlkit>=0.6.0,<0.7.0', 'typer>=0.2.1,<0.3.0']

entry_points = \
{'console_scripts': ['tyrannosaurus = tyrannosaurus.cli:cli']}

setup_kwargs = {
    'name': 'tyrannosaurus',
    'version': '0.0.3',
    'description': 'Generate ready-to-go Python projects.',
    'long_description': "# Tyrannosaurus Reqs\n\n[![Build status](https://img.shields.io/pypi/status/tyrannosaurus)](https://pypi.org/project/tyrannosaurus/)\n[![Latest version on PyPi](https://badge.fury.io/py/tyrannosaurus.svg)](https://pypi.org/project/tyrannosaurus/)\n[![Supported Python versions](https://img.shields.io/pypi/pyversions/tyrannosaurus.svg)](https://pypi.org/project/tyrannosaurus/)\n[![Documentation status](https://readthedocs.org/projects/tyrannosaurus/badge/?version=latest&style=flat-square)](https://readthedocs.org/projects/tyrannosaurus/)\n[![Travis](https://travis-ci.org/dmyersturnbull/tyrannosaurus.svg?branch=master)](https://travis-ci.org/dmyersturnbull/tyrannosaurus)\n[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)\n\nAn opinionated 2020 Python template.\nJust clone it and modify or run `tyrannosaurus new`.\n\n⚠ Status: Under development. The template works, but the command-line tool doesn't.\n\n[Poetry](https://github.com/python-poetry/poetry) is fantastic and assumed.\nNew projects are configured for:\n- Build: [Poetry](https://github.com/python-poetry/poetry), Tox, Conda, [DepHell](https://github.com/dephell/dephell), wheels, sdist\n- Test: Travis, Tox, pytest, Coverage\n- Style: Black, Flake8, MyPy, pycodestyle, pydocstyle\n- Hooks: [EditorConfig](https://editorconfig.org/), pre-commit-hooks\n- Documentation: ReadTheDocs, Sphinx, sphinx-autoapi\n- Publish: Twine, Docker, Conda-Forge (with [grayskull](https://github.com/marcelotrevisani/grayskull))\n\n\n### Synchronize repeated metadata\n\nProvides `tyrannosaurus sync` to copy metadata from your `pyproject.toml` other config files.\nThe information copied includes version, description, dependencies, maintainers, and style settings.\nYou can configure these under `[tool.tyrannosaurus.sources]` and `[tool.tyrannosaurus.targets]`.\nAlways generates backups before modifying.\n\nHere are most of the available synchronization targets:\n- Copyright, status, and date in `__init__.py`\n- Development dependencies between `tool.poetry.dev-dependencies`, `tool.poetry.extras`, and `tox.ini`\n- An `all` optional dependency list with all optional non-dev packages\n- Dependencies for building docs in `docs/conf.py`\n- Code line length between `isort`, `black`, and `pycodestyle`\n- Python version in `pyproject.toml`, `tox.ini`, `.travis.yml`, `black`, and `readthedocs.yml`\n- Copyright in `docs/conf.py`\n- Poetry version in `Dockerfile`\n- Authors and year listed in the license file\n- Dev versions in `.pre-commit-config.yaml`\n- `--maintainers` arg for Grayskull in `tox.ini`\n- `doc_url`, `dev_url`, and `license_file` in `meta.yaml`\n- Most recent version in `CHANGELOG.md` assuming [Keep a Changelog](https://keepachangelog.com/en/1.0.0/)\n\n### Reference of commands\n\nHere are some useful commands:\n- `pre-commit install` to configure pre-commit hooks\n- `tox` to sync metadata, build, install, build docs, and test\n- `poetry install` to install and nothing more\n- `poetry build` to build wheels and sdists and nothing more\n- `poetry bump` to bump dependency versions (major or minor)\n- `poetry publish` to upload to PyPi\n- `grayskull ${yourprojectname} --maintainers $(git config user.email) --output recipes/` to generate a Conda recipe\n- `tyrannosaurus sync` to sync metadata and nothing else\n- `tyrannosaurus clean --aggressive` to remove lots of temp files\n\n### Other things to set up\n- More pre-commit-config options, such as `check-yaml`\n- GPG keys with git: `git config --global user.signingkey`\n- GPG keys with Twine: use `twine -s`\n- A certificate with [Certbot](https://certbot.eff.org/) if you need one\n- Github labels, such as [Tyrannosaurus's labels](https://github.com/dmyersturnbull/tyrannosaurus/labels)\n\n### Uploading to Conda-Forge\n\nTo [upload a package to Conda-Forge](https://conda-forge.org/#add_recipe):\n1. Publish to PyPi, then run `grayskull` as above and then `tyrannosaurus sync`.\n2. Check over your new recipe in `recipes/projectname/meta.yaml`.\n3. Fork from [staged-recipes](https://github.com/conda-forge/staged-recipes).\n4. Copy your recipe from `recipes/projectname/meta.yaml` into the forked repo (keeping the directories).\n5. Make a pull request. If everything goes well, it will be on Conda-Forge soon!\n\n### Suggested standards to observe\n\nHere are some potentially useful standards:\n- [Semantic Versioning](https://semver.org/spec/v2.0.0.html)\n- [Keep a Changelog](https://keepachangelog.com/en/1.0.0/) recommendations.\n- [Conventional Commits](https://www.conventionalcommits.org/en/v1.0.0/).\n- According to taste, only Git rebase (never merge)\n\n\n### Building, extending, and contributing\n\n[New issues](https://github.com/dmyersturnbull/tyrannosaurus/issues) and pull requests are welcome.\n\nTyrannosaurus is licensed under the [Apache License, version 2.0](https://www.apache.org/licenses/LICENSE-2.0).\nThe author wrote it after making 18 Git commits trying to configure readthedocs, PyPi, and Tox.\nThis avoids that struggle for 99% of projects.\n\n\n\n```\n                                              .++++++++++++.\n                                           .++HHHHHHH^^HHH+.\n                                          .HHHHHHHHHH++-+-++.\n                                         .HHHHHHHHHHH:t~~~~~\n                                        .+HHHHHHHHHHjjjjjjjj.\n                                       .+NNNNNNNNN/++/:--..\n                              ........+NNNNNNNNNN.\n                          .++++BBBBBBBBBBBBBBB.\n .tttttttt:..           .++BBBBBBBBBBBBBBBBBBB.\n+tt+.      ``         .+BBBBBBBBBBBBBBBBBBBBB+++cccc.\nttt.               .-++BBBBBBBBBBBBBBBBBBBBBB++.ccc.\n+ttt++++:::::++++++BBBBBBBBBBBBBBBBBBBBBBB+..++.\n.+TTTTTTTTTTTTTBBBBBBBBBBBBBBBBBBBBBBBBB+.    .ccc.\n  .++TTTTTTTTTTBBBBBBBBBBBBBBBBBBBBBBBB+.      .cc.\n    ..:++++++++++++++++++BBBBBB++++BBBB.\n           .......      -LLLLL+. -LLLLL.\n                        -LLLL+.   -LLLL+.\n                        +LLL+       +LLL+\n                        +LL+         +ff+\n                        +ff++         +++:\n                        ++++:\n```\n",
    'author': 'Douglas Myers-Turnbull',
    'author_email': None,
    'maintainer': 'Douglas Myers-Turnbull',
    'maintainer_email': None,
    'url': 'https://github.com/dmyersturnbull/tyrannosaurus',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
